pub struct KV {Show 23 fields
pub key1: String,
pub key2: String,
pub string_val: String,
pub int_val: i64,
pub small_int: i16,
pub unsigned_val: u32,
pub float_val: f32,
pub double_val: f64,
pub boolean_val: bool,
pub opt_string: Option<String>,
pub opt_int: Option<i64>,
pub opt_float: Option<f64>,
pub opt_bool: Option<bool>,
pub uuid: Uuid,
pub opt_uuid: Option<Uuid>,
pub fixed_bytes: [u8; 16],
pub numbers: [i32; 4],
pub tags: Vec<String>,
pub scores: Vec<i32>,
pub floats: Option<Vec<f64>>,
pub shared_strings: Arc<Vec<String>>,
pub metadata: BTreeMap<String, String>,
pub counters: Option<BTreeMap<String, i64>>,
}Fields
key1: Stringkey2: Stringstring_val: Stringint_val: i64small_int: i16unsigned_val: u32float_val: f32double_val: f64boolean_val: boolopt_string: Option<String>opt_int: Option<i64>opt_float: Option<f64>opt_bool: Option<bool>uuid: Uuidopt_uuid: Option<Uuid>fixed_bytes: [u8; 16]numbers: [i32; 4]scores: Vec<i32>floats: Option<Vec<f64>>metadata: BTreeMap<String, String>counters: Option<BTreeMap<String, i64>>Trait Implementations
Sourceimpl Entity for KV
impl Entity for KV
Sourcetype PrimaryKey<'a> = (&'a String, &'a String)
type PrimaryKey<'a> = (&'a String, &'a String)
Primary key type. A tuple of field types (or single type) forming the PK.
Sourcefn primary_key_def() -> &'static [&'static ColumnDef]
fn primary_key_def() -> &'static [&'static ColumnDef]
Primary key column definitions. Empty if no PK defined.
Sourcefn primary_key<'a>(&'a self) -> Self::PrimaryKey<'a>
fn primary_key<'a>(&'a self) -> Self::PrimaryKey<'a>
Extract PK value(s) from
self.Sourcefn primary_key_expr(&self) -> impl Expression
fn primary_key_expr(&self) -> impl Expression
Build an expression matching the PK of
self.Sourcefn unique_defs() -> impl ExactSizeIterator<Item = impl ExactSizeIterator<Item = &'static ColumnDef>>
fn unique_defs() -> impl ExactSizeIterator<Item = impl ExactSizeIterator<Item = &'static ColumnDef>>
Unique constraint definitions.
Sourcefn row_values(&self) -> RowValues
fn row_values(&self) -> RowValues
Full row representation including all persisted columns.
Sourcefn create_table(
executor: &mut impl Executor,
if_not_exists: bool,
create_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
fn create_table(
executor: &mut impl Executor,
if_not_exists: bool,
create_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
Create table (and optional schema). Read more
Sourcefn drop_table(
executor: &mut impl Executor,
if_exists: bool,
drop_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
fn drop_table(
executor: &mut impl Executor,
if_exists: bool,
drop_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
Drop the table (and optional schema). Read more
Sourcefn insert_one(
executor: &mut impl Executor,
entity: impl AsEntity,
) -> impl Future<Output = Result<RowsAffected, Error>> + Send
fn insert_one( executor: &mut impl Executor, entity: impl AsEntity, ) -> impl Future<Output = Result<RowsAffected, Error>> + Send
Insert a single entity.
Sourcefn insert_many<It>(
executor: &mut impl Executor,
items: It,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
It: IntoIterator + Send,
<It as IntoIterator>::IntoIter: Send,
<It as IntoIterator>::Item: AsEntity,
fn insert_many<It>(
executor: &mut impl Executor,
items: It,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
It: IntoIterator + Send,
<It as IntoIterator>::IntoIter: Send,
<It as IntoIterator>::Item: AsEntity,
Bulk insert entities.
Sourcefn prepare_find<Exec>(
executor: &mut Exec,
condition: impl Expression,
limit: Option<u32>,
) -> impl Future<Output = Result<Query<<Exec as Executor>::Driver>, Error>> + Sendwhere
Exec: Executor,
fn prepare_find<Exec>(
executor: &mut Exec,
condition: impl Expression,
limit: Option<u32>,
) -> impl Future<Output = Result<Query<<Exec as Executor>::Driver>, Error>> + Sendwhere
Exec: Executor,
Prepare (but do not yet run) a SQL select query. Read more
Sourcefn find_one(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<Option<Self>, Error>> + Sendwhere
Self: Sized,
fn find_one(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<Option<Self>, Error>> + Sendwhere
Self: Sized,
Finds the first entity matching a condition expression. Read more
Sourcefn find_many(
executor: &mut impl Executor,
condition: impl Expression,
limit: Option<u32>,
) -> impl Stream<Item = Result<Self, Error>> + Sendwhere
Self: Sized,
fn find_many(
executor: &mut impl Executor,
condition: impl Expression,
limit: Option<u32>,
) -> impl Stream<Item = Result<Self, Error>> + Sendwhere
Self: Sized,
Streams entities matching a condition. Read more
Sourcefn delete_many(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
fn delete_many(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
Deletes all entities matching a condition. Read more
Sourceimpl Expression for KV
impl Expression for KV
Sourcefn write_query(
&self,
writer: &dyn SqlWriter,
context: &mut Context,
out: &mut DynQuery,
)
fn write_query( &self, writer: &dyn SqlWriter, context: &mut Context, out: &mut DynQuery, )
Generates the SQL representation of this expression.
Sourcefn accept_visitor(
&self,
_matcher: &mut dyn ExpressionVisitor,
_writer: &dyn SqlWriter,
_context: &mut Context,
_out: &mut DynQuery,
) -> bool
fn accept_visitor( &self, _matcher: &mut dyn ExpressionVisitor, _writer: &dyn SqlWriter, _context: &mut Context, _out: &mut DynQuery, ) -> bool
Traverses the expression with a visitor. Read more
Sourcefn as_identifier(&self, context: &mut Context) -> String
fn as_identifier(&self, context: &mut Context) -> String
Renders the expression as a string suitable for use as an identifier.
Sourceimpl KVColumnTrait for KV
impl KVColumnTrait for KV
const key1: ColumnRef
const key2: ColumnRef
const string_val: ColumnRef
const int_val: ColumnRef
const small_int: ColumnRef
const unsigned_val: ColumnRef
const float_val: ColumnRef
const double_val: ColumnRef
const boolean_val: ColumnRef
const opt_string: ColumnRef
const opt_int: ColumnRef
const opt_float: ColumnRef
const opt_bool: ColumnRef
const uuid: ColumnRef
const opt_uuid: ColumnRef
const fixed_bytes: ColumnRef
const numbers: ColumnRef
const scores: ColumnRef
const floats: ColumnRef
const metadata: ColumnRef
const counters: ColumnRef
Sourceimpl OpPrecedence for KV
impl OpPrecedence for KV
Sourcefn precedence(&self, _: &dyn SqlWriter) -> i32
fn precedence(&self, _: &dyn SqlWriter) -> i32
Lower numbers bind weaker, writers parenthesize when child precedence <= operator precedence.
impl StructuralPartialEq for KV