pub struct ReservedWords {
pub id: i32,
pub select_field: String,
pub where_field: i32,
pub group_field: bool,
pub order_field: Option<String>,
pub limit_field: f64,
}Fields
id: i32select_field: Stringwhere_field: i32group_field: boolorder_field: Option<String>limit_field: f64Trait Implementations
Sourceimpl AsEntity for ReservedWords
impl AsEntity for ReservedWords
type Entity = ReservedWords
fn as_entity(&self) -> &ReservedWords
Sourceimpl AsEntity for &ReservedWords
impl AsEntity for &ReservedWords
type Entity = ReservedWords
fn as_entity(&self) -> &ReservedWords
Sourceimpl Debug for ReservedWords
impl Debug for ReservedWords
Sourceimpl Entity for ReservedWords
impl Entity for ReservedWords
Sourcetype PrimaryKey<'a> = (&'a i32,)
type PrimaryKey<'a> = (&'a i32,)
Primary key type. A tuple of field types (or single type) forming the PK.
Sourcefn primary_key_def() -> &'static [&'static ColumnDef]
fn primary_key_def() -> &'static [&'static ColumnDef]
Primary key column definitions. Empty if no PK defined.
Sourcefn primary_key<'a>(&'a self) -> Self::PrimaryKey<'a>
fn primary_key<'a>(&'a self) -> Self::PrimaryKey<'a>
Extract PK value(s) from
self.Sourcefn primary_key_expr(&self) -> impl Expression
fn primary_key_expr(&self) -> impl Expression
Build an expression matching the PK of
self.Sourcefn unique_defs() -> impl ExactSizeIterator<Item = impl ExactSizeIterator<Item = &'static ColumnDef>>
fn unique_defs() -> impl ExactSizeIterator<Item = impl ExactSizeIterator<Item = &'static ColumnDef>>
Unique constraint definitions.
Sourcefn row_values(&self) -> RowValues
fn row_values(&self) -> RowValues
Full row representation including all persisted columns.
Sourcefn create_table(
executor: &mut impl Executor,
if_not_exists: bool,
create_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
fn create_table(
executor: &mut impl Executor,
if_not_exists: bool,
create_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
Create table (and optional schema). Read more
Sourcefn drop_table(
executor: &mut impl Executor,
if_exists: bool,
drop_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
fn drop_table(
executor: &mut impl Executor,
if_exists: bool,
drop_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
Drop the table (and optional schema). Read more
Sourcefn insert_one(
executor: &mut impl Executor,
entity: impl AsEntity,
) -> impl Future<Output = Result<RowsAffected, Error>> + Send
fn insert_one( executor: &mut impl Executor, entity: impl AsEntity, ) -> impl Future<Output = Result<RowsAffected, Error>> + Send
Insert a single entity.
Sourcefn insert_many<It>(
executor: &mut impl Executor,
items: It,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
It: IntoIterator + Send,
<It as IntoIterator>::IntoIter: Send,
<It as IntoIterator>::Item: AsEntity,
fn insert_many<It>(
executor: &mut impl Executor,
items: It,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
It: IntoIterator + Send,
<It as IntoIterator>::IntoIter: Send,
<It as IntoIterator>::Item: AsEntity,
Bulk insert entities.
Sourcefn prepare_find<Exec>(
executor: &mut Exec,
condition: impl Expression,
limit: Option<u32>,
) -> impl Future<Output = Result<Query<<Exec as Executor>::Driver>, Error>> + Sendwhere
Exec: Executor,
fn prepare_find<Exec>(
executor: &mut Exec,
condition: impl Expression,
limit: Option<u32>,
) -> impl Future<Output = Result<Query<<Exec as Executor>::Driver>, Error>> + Sendwhere
Exec: Executor,
Prepare (but do not yet run) a SQL select query. Read more
Sourcefn find_one(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<Option<Self>, Error>> + Sendwhere
Self: Sized,
fn find_one(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<Option<Self>, Error>> + Sendwhere
Self: Sized,
Finds the first entity matching a condition expression. Read more
Sourcefn find_many(
executor: &mut impl Executor,
condition: impl Expression,
limit: Option<u32>,
) -> impl Stream<Item = Result<Self, Error>> + Sendwhere
Self: Sized,
fn find_many(
executor: &mut impl Executor,
condition: impl Expression,
limit: Option<u32>,
) -> impl Stream<Item = Result<Self, Error>> + Sendwhere
Self: Sized,
Streams entities matching a condition. Read more
Sourcefn delete_many(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
fn delete_many(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
Deletes all entities matching a condition. Read more
Sourceimpl Expression for ReservedWords
impl Expression for ReservedWords
Sourcefn write_query(
&self,
writer: &dyn SqlWriter,
context: &mut Context,
out: &mut DynQuery,
)
fn write_query( &self, writer: &dyn SqlWriter, context: &mut Context, out: &mut DynQuery, )
Generates the SQL representation of this expression.
Sourcefn accept_visitor(
&self,
_matcher: &mut dyn ExpressionVisitor,
_writer: &dyn SqlWriter,
_context: &mut Context,
_out: &mut DynQuery,
) -> bool
fn accept_visitor( &self, _matcher: &mut dyn ExpressionVisitor, _writer: &dyn SqlWriter, _context: &mut Context, _out: &mut DynQuery, ) -> bool
Traverses the expression with a visitor. Read more
Sourcefn as_identifier(&self, context: &mut Context) -> String
fn as_identifier(&self, context: &mut Context) -> String
Renders the expression as a string suitable for use as an identifier.
Sourceimpl OpPrecedence for ReservedWords
impl OpPrecedence for ReservedWords
Sourcefn precedence(&self, _: &dyn SqlWriter) -> i32
fn precedence(&self, _: &dyn SqlWriter) -> i32
Lower numbers bind weaker, writers parenthesize when child precedence <= operator precedence.
Sourceimpl PartialEq for ReservedWords
impl PartialEq for ReservedWords
Sourceimpl ReservedWordsColumnTrait for ReservedWords
impl ReservedWordsColumnTrait for ReservedWords
const id: ColumnRef
const select_field: ColumnRef
const where_field: ColumnRef
const group_field: ColumnRef
const order_field: ColumnRef
const limit_field: ColumnRef
impl StructuralPartialEq for ReservedWords