pub struct Trade {Show 13 fields
pub trade: u64,
pub order: Uuid,
pub symbol: String,
pub isin: [char; 12],
pub price: FixedDecimal<18, 4>,
pub quantity: u32,
pub execution_time: Passive<PrimitiveDateTime>,
pub currency: Option<String>,
pub is_internalized: bool,
pub venue: Option<String>,
pub child_trade_ids: Option<Vec<i64>>,
pub metadata: Option<Box<[u8]>>,
pub tags: Option<BTreeMap<String, String>>,
}Fields
trade: u64order: Uuidsymbol: StringTicker symbol
isin: [char; 12]price: FixedDecimal<18, 4>quantity: u32execution_time: Passive<PrimitiveDateTime>currency: Option<String>is_internalized: boolvenue: Option<String>Exchange
child_trade_ids: Option<Vec<i64>>metadata: Option<Box<[u8]>>Trait Implementations
Sourceimpl Entity for Trade
impl Entity for Trade
Sourcetype PrimaryKey<'a> = (&'a u64, &'a Passive<PrimitiveDateTime>)
type PrimaryKey<'a> = (&'a u64, &'a Passive<PrimitiveDateTime>)
Primary key type. Tuple of the types of the fields forming the primary key.
Sourcefn columns() -> &'static [ColumnDef]
fn columns() -> &'static [ColumnDef]
Returns all declared column definitions in declaration order.
Sourcefn primary_key_def() -> &'static [&'static ColumnDef]
fn primary_key_def() -> &'static [&'static ColumnDef]
Iterator over columns forming the primary key. Empty iterator means no PK.
Sourcefn primary_key<'a>(&'a self) -> Self::PrimaryKey<'a>
fn primary_key<'a>(&'a self) -> Self::PrimaryKey<'a>
Extracts the primary key value(s) from
self.Sourcefn unique_defs() -> impl ExactSizeIterator<Item = impl ExactSizeIterator<Item = &'static ColumnDef>>
fn unique_defs() -> impl ExactSizeIterator<Item = impl ExactSizeIterator<Item = &'static ColumnDef>>
Returns an iterator over unique constraint definitions.
Sourcefn row_filtered(&self) -> Box<[(&'static str, Value)]>
fn row_filtered(&self) -> Box<[(&'static str, Value)]>
Returns a filtered mapping of column name to value, typically excluding
auto-generated or default-only columns.
Sourcefn from_row(row: RowLabeled) -> Result<Self>
fn from_row(row: RowLabeled) -> Result<Self>
Constructs
Self from a labeled database row. Read moreSourcefn find_pk(
executor: &mut impl Executor,
primary_key: &Self::PrimaryKey<'_>,
) -> impl Future<Output = Result<Option<Self>>>
fn find_pk( executor: &mut impl Executor, primary_key: &Self::PrimaryKey<'_>, ) -> impl Future<Output = Result<Option<Self>>>
Finds an entity by primary key. Read more
Sourcefn delete_one(
executor: &mut impl Executor,
primary_key: Self::PrimaryKey<'_>,
) -> impl Future<Output = Result<RowsAffected>> + Sendwhere
Self: Sized,
fn delete_one(
executor: &mut impl Executor,
primary_key: Self::PrimaryKey<'_>,
) -> impl Future<Output = Result<RowsAffected>> + Sendwhere
Self: Sized,
Deletes exactly one entity by primary key. Read more
Sourcefn create_table(
executor: &mut impl Executor,
if_not_exists: bool,
create_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
fn create_table(
executor: &mut impl Executor,
if_not_exists: bool,
create_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
Creates the underlying table (and optionally schema) if requested. Read more
Sourcefn drop_table(
executor: &mut impl Executor,
if_exists: bool,
drop_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
fn drop_table(
executor: &mut impl Executor,
if_exists: bool,
drop_schema: bool,
) -> impl Future<Output = Result<(), Error>> + Sendwhere
Self: Sized,
Drops the underlying table (and optionally schema) if requested. Read more
Sourcefn insert_one(
executor: &mut impl Executor,
entity: &impl Entity,
) -> impl Future<Output = Result<RowsAffected, Error>> + Send
fn insert_one( executor: &mut impl Executor, entity: &impl Entity, ) -> impl Future<Output = Result<RowsAffected, Error>> + Send
Inserts a single entity row. Read more
Sourcefn insert_many<'a, It>(
executor: &mut impl Executor,
items: It,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized + 'a,
It: IntoIterator<Item = &'a Self> + Send,
<It as IntoIterator>::IntoIter: Send,
fn insert_many<'a, It>(
executor: &mut impl Executor,
items: It,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized + 'a,
It: IntoIterator<Item = &'a Self> + Send,
<It as IntoIterator>::IntoIter: Send,
Multiple insert for a homogeneous iterator of entities. Read more
Sourcefn prepare_find<Exec>(
executor: &mut Exec,
condition: impl Expression,
limit: Option<u32>,
) -> impl Future<Output = Result<Query<<Exec as Executor>::Driver>, Error>>where
Exec: Executor,
fn prepare_find<Exec>(
executor: &mut Exec,
condition: impl Expression,
limit: Option<u32>,
) -> impl Future<Output = Result<Query<<Exec as Executor>::Driver>, Error>>where
Exec: Executor,
Prepare (but do not yet run) a SQL select query. Read more
Sourcefn find_one(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<Option<Self>, Error>> + Sendwhere
Self: Sized,
fn find_one(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<Option<Self>, Error>> + Sendwhere
Self: Sized,
Finds the first entity matching a condition expression. Read more
Sourcefn find_many(
executor: &mut impl Executor,
condition: impl Expression,
limit: Option<u32>,
) -> impl Stream<Item = Result<Self, Error>> + Sendwhere
Self: Sized,
fn find_many(
executor: &mut impl Executor,
condition: impl Expression,
limit: Option<u32>,
) -> impl Stream<Item = Result<Self, Error>> + Sendwhere
Self: Sized,
Streams entities matching a condition. Read more
Sourcefn delete_many(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
fn delete_many(
executor: &mut impl Executor,
condition: impl Expression,
) -> impl Future<Output = Result<RowsAffected, Error>> + Sendwhere
Self: Sized,
Deletes all entities matching a condition. Read more
Sourceimpl TradeColumnTrait for Trade
impl TradeColumnTrait for Trade
const trade: ColumnRef
const order: ColumnRef
const symbol: ColumnRef
const isin: ColumnRef
const price: ColumnRef
const quantity: ColumnRef
const execution_time: ColumnRef
const currency: ColumnRef
const is_internalized: ColumnRef
const venue: ColumnRef
const child_trade_ids: ColumnRef
const metadata: ColumnRef
impl StructuralPartialEq for Trade